/*
  IDC utility library (c) lallous <lallousx86(at)yahoo.com>

  You may use this library free of charge as long as you keep appropriate copyright and credits.

  History
  ----------
  - 02/02/2004
  Initial version

  - 03/23/2004
  Added Global variables helper functions
  Added FunctionEnd()
  Added GetFilePath()

  - 09/23/2004
  Added HowManyLines()

*/

// Returns the file's path given its full filename
static GetFilePath(path)
{
  auto s, i;
  s = path;
  for (i=strlen(s)-1;i>0;i--)
  {
    if (substr(s, i, i+1) == "\\")
      break;
  }
  return substr(s, 0, i+1);
}

// Returns a C string given an address
static getCName(ea)
{
  auto name, ch;
  
  name = "";
  while (ch = Byte(ea++))
    name = name + ch;

  return name;
}

// Returns a function's start given an address within its range
static FunctionStart(ea)
{
  return LocByName(GetFunctionName(ea));
}

// Returns a function's end given an address within its range
static FunctionEnd(ea)
{
  return FindFuncEnd(FunctionStart(ea));
}

// Returns the number of lines in a given address range
static HowManyLines(start, end)
{
  auto x;

  x = 0;
  while (start != BADADDR)
  {
    x++;
    start = NextHead(start, end);
  }
  return x;
}

// ============================================================================
//                        GLOBAL VARIABLES HELPER FUNCTIONS
// ============================================================================
#define GLOBAL_VARS "GLOBALS"

#define GetGlobalVarLong(gvar)        GetArrayElement(AR_LONG, GetArrayId(GLOBAL_VARS), gvar)
#define SetGlobalVarLong(gvar, val)   SetArrayLong(GetArrayId(GLOBAL_VARS), gvar, val)

#define GetGlobalVarString(gvar)      GetArrayElement(AR_STR, GetArrayId(GLOBAL_VARS), gvar)
#define SetGlobalVarString(gvar, val) SetArrayString(GetArrayId(GLOBAL_VARS), gvar, val)

// ***********************************************
// Call this function once in main() so that
// we initialize global variables
static InitGlobalVars()
{
  auto global;

  global = CreateArray(GLOBAL_VARS);

  // already exists?
  if (global == -1)
  {
    global = GetArrayId(GLOBAL_VARS);
    // array not found? wasn't created at all!?!
    if (global == -1)
      return 0;
  }
  return 1;
}